@@ -5,7 +5,7 @@ import pandas as pd
 
 from archimedes.data.common import get_api_base_url_v2
 from archimedes.utils import get_end_date, get_start_date
-from archimedes.utils.api_request import make_api_request
+from archimedes.utils.api_request import api
 from archimedes.utils.split import get_queries_observation_json
 from archimedes.utils.threaded_executor import execute_many
 from archimedes.utils.utils import datetime_to_iso_format
@@ -26,20 +26,29 @@ def get_intraday_trades(
 
     Example:
         >>> import archimedes
-        >>> archimedes.get(
+        >>> archimedes.get_intraday_trades(
         >>>     price_areas=["NO1",],
         >>>     start="2020-06-20T04:00:00+00:00",
         >>>     end="2020-06-20T09:00:00+00:00",
         >>> )
-                from_dt to_dt   series_id   version price   trade_time  buy_area    sell_area   attributes
-        0	2022-03-01T00:00:00+00:00	2022-03-01T01:00:00+00:00	NP/IntradayTrades	1646193645	146.63	2022-02-28T17:02:06.934+0000	OPX	NO1	{'price': 146.63,...,  'product_code': 'PH-20220301-01'}
-        1	2022-03-01T00:00:00+00:00	2022-03-01T01:00:00+00:00	NP/IntradayTrades	1646193645	146.63	2022-02-28T17:02:06.934+0000	OPX	NO1	{'price': 146.63,... , 'product_code': 'PH-20220301-01'}
-        2	2022-03-01T00:00:00+00:00	2022-03-01T01:00:00+00:00	NP/IntradayTrades	1646193645	146.63	2022-02-28T17:02:06.934+0000	OPX	NO1	{'price': 146.63, ..., 'product_code': 'PH-20220301-01'}
-        ...
-        155	2022-03-01T23:00:00+00:00	2022-03-02T00:00:00+00:00	NP/IntradayTrades	1646193645	148.99	2022-03-01T13:05:40.934+0000	NL	NO1	{'price': 148.99,... , 'product_code': 'PH-20220301-24'}
-        156	2022-03-01T23:00:00+00:00	2022-03-02T00:00:00+00:00	NP/IntradayTrades	1646193645	148.8	2022-03-01T12:57:58.777+0000	NO1	FI	{'price': 148.8,...,  'product_code': 'PH-20220301-24'}
-        157	2022-03-01T23:00:00+00:00	2022-03-02T00:00:00+00:00	NP/IntradayTrades	1646193645	148.8	2022-03-01T12:58:02.115+0000	NO1	FI	{'price': 148.8, ... , 'product_code': 'PH-20220301-24'}
-
+                              from_dt                      to_dt          series_id  price  volume                    trade_time buy_area sell_area                                         attributes
+        0   2020-06-20T04:00:00+00:00  2020-06-20T05:00:00+00:00  NP/IntradayTrades   7.05     0.9  2020-06-19T15:55:24.817+0000      OPX       NO1  {'price': 7.05, 'buy_area': 'OPX', 'currency':...
+        1   2020-06-20T05:00:00+00:00  2020-06-20T06:00:00+00:00  NP/IntradayTrades   6.80     0.9  2020-06-19T15:55:24.817+0000      OPX       NO1  {'price': 6.8, 'buy_area': 'OPX', 'currency': ...
+        2   2020-06-20T06:00:00+00:00  2020-06-20T07:00:00+00:00  NP/IntradayTrades   7.75     0.9  2020-06-19T15:55:24.817+0000      OPX       NO1  {'price': 7.75, 'buy_area': 'OPX', 'currency':...
+        3   2020-06-20T07:00:00+00:00  2020-06-20T08:00:00+00:00  NP/IntradayTrades   1.70     0.1  2020-06-19T20:20:14.765+0000       FI       NO1  {'price': 1.7, 'buy_area': 'FI', 'currency': '...
+        4   2020-06-20T07:00:00+00:00  2020-06-20T08:00:00+00:00  NP/IntradayTrades   8.30     0.9  2020-06-19T15:55:24.817+0000      OPX       NO1  {'price': 8.3, 'buy_area': 'OPX', 'currency': ...
+        5   2020-06-20T08:00:00+00:00  2020-06-20T09:00:00+00:00  NP/IntradayTrades   2.60     2.0  2020-06-19T20:19:56.057+0000      OPX       NO1  {'price': 2.6, 'buy_area': 'OPX', 'currency': ...
+        6   2020-06-20T08:00:00+00:00  2020-06-20T09:00:00+00:00  NP/IntradayTrades   2.60     6.0  2020-06-19T20:19:56.057+0000      OPX       NO1  {'price': 2.6, 'buy_area': 'OPX', 'currency': ...
+        7   2020-06-20T08:00:00+00:00  2020-06-20T09:00:00+00:00  NP/IntradayTrades   2.60     6.0  2020-06-19T20:19:56.057+0000      OPX       NO1  {'price': 2.6, 'buy_area': 'OPX', 'currency': ...
+        8   2020-06-20T08:00:00+00:00  2020-06-20T09:00:00+00:00  NP/IntradayTrades   2.60     6.0  2020-06-19T20:19:56.057+0000      OPX       NO1  {'price': 2.6, 'buy_area': 'OPX', 'currency': ...
+        9   2020-06-20T08:00:00+00:00  2020-06-20T09:00:00+00:00  NP/IntradayTrades   2.60     0.9  2020-06-19T20:19:56.057+0000      OPX       NO1  {'price': 2.6, 'buy_area': 'OPX', 'currency': ...
+        10  2020-06-20T08:00:00+00:00  2020-06-20T09:00:00+00:00  NP/IntradayTrades   2.60     6.0  2020-06-19T20:19:56.057+0000      OPX       NO1  {'price': 2.6, 'buy_area': 'OPX', 'currency': ...
+        11  2020-06-20T08:00:00+00:00  2020-06-20T09:00:00+00:00  NP/IntradayTrades   2.60     0.1  2020-06-19T20:19:56.057+0000      OPX       NO1  {'price': 2.6, 'buy_area': 'OPX', 'currency': ...
+        12  2020-06-20T08:00:00+00:00  2020-06-20T09:00:00+00:00  NP/IntradayTrades   2.60     6.0  2020-06-19T20:19:56.057+0000      OPX       NO1  {'price': 2.6, 'buy_area': 'OPX', 'currency': ...
+        13  2020-06-20T08:00:00+00:00  2020-06-20T09:00:00+00:00  NP/IntradayTrades   2.60     6.0  2020-06-19T20:19:56.057+0000      OPX       NO1  {'price': 2.6, 'buy_area': 'OPX', 'currency': ...
+        14  2020-06-20T08:00:00+00:00  2020-06-20T09:00:00+00:00  NP/IntradayTrades   2.60     6.0  2020-06-19T20:19:56.057+0000      OPX       NO1  {'price': 2.6, 'buy_area': 'OPX', 'currency': ...
+        15  2020-06-20T08:00:00+00:00  2020-06-20T09:00:00+00:00  NP/IntradayTrades   2.60     5.1  2020-06-19T20:19:56.057+0000      OPX       NO1  {'price': 2.6, 'buy_area': 'OPX', 'currency': ...
+        16  2020-06-20T08:00:00+00:00  2020-06-20T09:00:00+00:00  NP/IntradayTrades   9.90     0.9  2020-06-19T15:55:24.817+0000      OPX       NO1  {'price': 9.9, 'buy_area': 'OPX', 'currency': ...
 
     Args:
         price_areas (List[str], optional): The price areas to pick, all price areas if None. Defaults to None.
@@ -79,7 +88,7 @@ def get_intraday_trades(
         for query in queries
     ]
 
-    observation_data = execute_many(make_api_request, params_array)
+    observation_data = execute_many(api.request, params_array)
 
     if len(observation_data) == 0:
         return pd.DataFrame(
@@ -89,6 +98,7 @@ def get_intraday_trades(
                 "series_id",
                 "version",
                 "price",
+                "volume",
                 "trade_time",
                 "buy_area",
                 "sell_area",
@@ -99,6 +109,7 @@ def get_intraday_trades(
         {
             **i,
             "price": i["value"].get("price"),
+            "volume": i["value"].get("quantity"),
             "trade_time": i["value"].get("trade_time"),
         }
         for i in observation_data
