@@ -5,7 +5,7 @@ import pandas as pd
 
 from archimedes.data.common import get_api_base_url_v2
 from archimedes.utils import get_end_date, get_start_date
-from archimedes.utils.api_request import make_api_request
+from archimedes.utils.api_request import api
 from archimedes.utils.split import get_queries_observation, get_queries_observation_json
 from archimedes.utils.threaded_executor import execute_many
 from archimedes.utils.utils import datetime_to_iso_format
@@ -88,7 +88,7 @@ def get(  # pylint:disable=too-many-locals
         request_url_path = (
             "data" if request_type == "observations" else "observation_json"
         )
-        query_result = make_api_request(
+        query_result = api.request(
             f"{get_api_base_url_v2()}/{request_url_path}/get",
             params=params,
             access_token=access_token,
@@ -200,10 +200,10 @@ def get_latest(
 
 def _split_series_ids(series_ids, access_token=None):
     base_url = get_api_base_url_v2()
-    all_series_ids_observations = make_api_request(
+    all_series_ids_observations = api.request(
         f"{base_url}/data/list_ids", access_token=access_token
     )
-    all_series_ids_observations_json = make_api_request(
+    all_series_ids_observations_json = api.request(
         f"{base_url}/observation_json/list_ids",
         access_token=access_token,
     )
